Type: Package
Package: see
Title: Model Visualisation Toolbox for 'easystats' and 'ggplot2'
Version: 0.9.0
Authors@R: 
    c(person(given = "Daniel",
             family = "Lüdecke",
             role = c("aut", "ctb"),
             email = "d.luedecke@uke.de",
             comment = c(ORCID = "0000-0002-8895-3206", Twitter = "@strengejacke")),
      person(given = "Dominique",
             family = "Makowski",
             role = c("aut", "inv"),
             email = "dom.makowski@gmail.com",
             comment = c(ORCID = "0000-0001-5375-9967", Twitter = "@Dom_Makowski")),
      person(given = "Indrajeet",
             family = "Patil",
             role = c("aut", "cre"),
             email = "patilindrajeet.science@gmail.com",
             comment = c(ORCID = "0000-0003-1995-6531", Twitter = "@patilindrajeets")),
      person(given = "Mattan S.",
             family = "Ben-Shachar",
             role = c("aut", "ctb"),
             email = "matanshm@post.bgu.ac.il",
             comment = c(ORCID = "0000-0002-4287-4801", Twitter = "@mattansb")),
      person(given = "Brenton M.",
             family = "Wiernik",
             role = c("aut", "ctb"),
             email = "brenton@wiernik.org",
             comment = c(ORCID = "0000-0001-9560-6336")),
      person(given = "Philip",
             family = "Waggoner",
             role = c("aut", "ctb"),
             email = "philip.waggoner@gmail.com",
             comment = c(ORCID = "0000-0002-7825-7573")),
      person(given = "Jeffrey R.",
             family = "Stevens",
             role = "ctb",
             email = "jeffrey.r.stevens@gmail.com",
             comment = c(ORCID = "0000-0003-2375-1360")),
      person(given = "Matthew",
             family = "Smith",
             role = "rev",
             email = "M.Smith3@napier.ac.uk",
             comment = c(Twitter = "@SmithMatt90")),
      person(given = "Jakob",
             family = "Bossek",
             role = "rev",
             email = "bossek@wi.uni-muenster.de",
             comment = c(Twitter = "@BossekJakob")))
Maintainer: Indrajeet Patil <patilindrajeet.science@gmail.com>
Description: Provides plotting utilities supporting packages in the 'easystats'
    ecosystem (<https://github.com/easystats/easystats>) and some extra themes,
    geoms, and scales for 'ggplot2'. Color scales are based on
    <https://materialui.co/>.
    References: Lüdecke et al. (2021) <doi:10.21105/joss.03393>.
License: MIT + file LICENSE
URL: https://easystats.github.io/see/
BugReports: https://github.com/easystats/see/issues
Depends: graphics, grDevices, R (>= 4.0), stats
Imports: bayestestR (>= 0.14.0), correlation (>= 0.8.5), datawizard (>=
        0.12.3), effectsize (>= 0.8.9), ggplot2, insight (>= 0.20.4),
        modelbased (>= 0.8.8), parameters (>= 0.22.1), performance (>=
        0.12.3)
Suggests: BH, brms, curl, DHARMa, emmeans, factoextra, ggdag, ggdist,
        ggraph, ggrepel, ggridges, ggside, glmmTMB, grid, httr, httr2,
        lavaan, lme4, logspline, MASS, mclust, merDeriv, mgcv, metafor,
        NbClust, nFactors, patchwork (>= 1.2.0), poorman, psych,
        qqplotr (>= 0.0.6), randomForest, RcppEigen, rlang, rmarkdown,
        rstanarm, scales (>= 1.3.0), splines, testthat (>= 3.2.1),
        tidygraph, vdiffr (>= 1.0.7)
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.2
Config/testthat/edition: 3
Config/testthat/parallel: true
Config/Needs/website: easystats/easystatstemplate
Config/rcmdcheck/ignore-inconsequential-notes: true
NeedsCompilation: no
Packaged: 2024-09-05 15:25:48 UTC; indrajeetpatil
Author: Daniel Lüdecke [aut, ctb] (<https://orcid.org/0000-0002-8895-3206>,
    @strengejacke),
  Dominique Makowski [aut, inv] (<https://orcid.org/0000-0001-5375-9967>,
    @Dom_Makowski),
  Indrajeet Patil [aut, cre] (<https://orcid.org/0000-0003-1995-6531>,
    @patilindrajeets),
  Mattan S. Ben-Shachar [aut, ctb]
    (<https://orcid.org/0000-0002-4287-4801>, @mattansb),
  Brenton M. Wiernik [aut, ctb] (<https://orcid.org/0000-0001-9560-6336>),
  Philip Waggoner [aut, ctb] (<https://orcid.org/0000-0002-7825-7573>),
  Jeffrey R. Stevens [ctb] (<https://orcid.org/0000-0003-2375-1360>),
  Matthew Smith [rev] (@SmithMatt90),
  Jakob Bossek [rev] (@BossekJakob)
Repository: CRAN
Date/Publication: 2024-09-06 04:30:02 UTC
Built: R 4.4.1; ; 2024-09-06 14:05:50 UTC; unix
