# Generated by roxygen2: do not edit by hand

S3method(data_plot,bayestestR_eti)
S3method(data_plot,bayestestR_hdi)
S3method(data_plot,check_outliers)
S3method(data_plot,compare_performance)
S3method(data_plot,estimate_contrasts)
S3method(data_plot,estimate_density)
S3method(data_plot,estimate_density_df)
S3method(data_plot,hdi)
S3method(data_plot,map_estimate)
S3method(data_plot,n_clusters)
S3method(data_plot,n_factors)
S3method(data_plot,p_direction)
S3method(data_plot,p_significance)
S3method(data_plot,parameters_brms_meta)
S3method(data_plot,parameters_distribution)
S3method(data_plot,parameters_efa)
S3method(data_plot,parameters_pca)
S3method(data_plot,parameters_sem)
S3method(data_plot,parameters_simulate)
S3method(data_plot,performance_pp_check)
S3method(data_plot,point_estimate)
S3method(data_plot,rope)
S3method(data_plot,see_compare_parameters)
S3method(plot,datawizard_table)
S3method(plot,datawizard_tables)
S3method(plot,see_bayesfactor_models)
S3method(plot,see_bayesfactor_parameters)
S3method(plot,see_bayesfactor_savagedickey)
S3method(plot,see_binned_residuals)
S3method(plot,see_check_collinearity)
S3method(plot,see_check_dag)
S3method(plot,see_check_distribution)
S3method(plot,see_check_distribution_numeric)
S3method(plot,see_check_heteroscedasticity)
S3method(plot,see_check_homogeneity)
S3method(plot,see_check_model)
S3method(plot,see_check_normality)
S3method(plot,see_check_outliers)
S3method(plot,see_check_overdisp)
S3method(plot,see_check_residuals)
S3method(plot,see_compare_parameters)
S3method(plot,see_compare_performance)
S3method(plot,see_effectsize_table)
S3method(plot,see_equivalence_test)
S3method(plot,see_equivalence_test_df)
S3method(plot,see_equivalence_test_effectsize)
S3method(plot,see_equivalence_test_lm)
S3method(plot,see_estimate_contrasts)
S3method(plot,see_estimate_density)
S3method(plot,see_estimate_density_df)
S3method(plot,see_eti)
S3method(plot,see_hdi)
S3method(plot,see_n_clusters)
S3method(plot,see_n_factors)
S3method(plot,see_p_direction)
S3method(plot,see_p_function)
S3method(plot,see_p_significance)
S3method(plot,see_parameters_brms_meta)
S3method(plot,see_parameters_distribution)
S3method(plot,see_parameters_efa)
S3method(plot,see_parameters_model)
S3method(plot,see_parameters_pca)
S3method(plot,see_parameters_sem)
S3method(plot,see_parameters_simulate)
S3method(plot,see_performance_pp_check)
S3method(plot,see_performance_roc)
S3method(plot,see_performance_simres)
S3method(plot,see_point_estimate)
S3method(plot,see_rope)
S3method(plot,see_si)
S3method(plot,see_visualisation_recipe)
S3method(plot,see_visualisation_recipes)
S3method(print,data_plot)
S3method(print,see_check_model)
S3method(print,see_performance_pp_check)
export(add_plot_attributes)
export(bluebrown_colors)
export(coord_radar)
export(data_plot)
export(flat_colors)
export(geom_binomdensity)
export(geom_count2)
export(geom_count_borderless)
export(geom_from_list)
export(geom_jitter2)
export(geom_jitter_borderless)
export(geom_point2)
export(geom_point_borderless)
export(geom_pointrange2)
export(geom_pointrange_borderless)
export(geom_pooljitter)
export(geom_poolpoint)
export(geom_violindot)
export(geom_violinhalf)
export(geoms_from_list)
export(golden_ratio)
export(material_colors)
export(metro_colors)
export(oi_colors)
export(okabeito_colors)
export(palette_bluebrown)
export(palette_colorhex)
export(palette_flat)
export(palette_material)
export(palette_metro)
export(palette_oi)
export(palette_okabeito)
export(palette_pizza)
export(palette_see)
export(palette_social)
export(pizza_colors)
export(plots)
export(scale_color_bluebrown)
export(scale_color_bluebrown_c)
export(scale_color_bluebrown_d)
export(scale_color_colorhex)
export(scale_color_colorhex_c)
export(scale_color_colorhex_d)
export(scale_color_flat)
export(scale_color_flat_c)
export(scale_color_flat_d)
export(scale_color_material)
export(scale_color_material_c)
export(scale_color_material_d)
export(scale_color_metro)
export(scale_color_metro_c)
export(scale_color_metro_d)
export(scale_color_oi)
export(scale_color_okabeito)
export(scale_color_pizza)
export(scale_color_pizza_c)
export(scale_color_pizza_d)
export(scale_color_see)
export(scale_color_see_c)
export(scale_color_see_d)
export(scale_color_social)
export(scale_color_social_c)
export(scale_color_social_d)
export(scale_colour_bluebrown)
export(scale_colour_bluebrown_c)
export(scale_colour_bluebrown_d)
export(scale_colour_colorhex)
export(scale_colour_colorhex_c)
export(scale_colour_colorhex_d)
export(scale_colour_flat)
export(scale_colour_flat_c)
export(scale_colour_flat_d)
export(scale_colour_material)
export(scale_colour_material_c)
export(scale_colour_material_d)
export(scale_colour_metro)
export(scale_colour_metro_c)
export(scale_colour_metro_d)
export(scale_colour_oi)
export(scale_colour_okabeito)
export(scale_colour_pizza)
export(scale_colour_pizza_c)
export(scale_colour_pizza_d)
export(scale_colour_see)
export(scale_colour_see_c)
export(scale_colour_see_d)
export(scale_colour_social)
export(scale_colour_social_c)
export(scale_colour_social_d)
export(scale_fill_bluebrown)
export(scale_fill_bluebrown_c)
export(scale_fill_bluebrown_d)
export(scale_fill_colorhex)
export(scale_fill_colorhex_c)
export(scale_fill_colorhex_d)
export(scale_fill_flat)
export(scale_fill_flat_c)
export(scale_fill_flat_d)
export(scale_fill_material)
export(scale_fill_material_c)
export(scale_fill_material_d)
export(scale_fill_metro)
export(scale_fill_metro_c)
export(scale_fill_metro_d)
export(scale_fill_oi)
export(scale_fill_okabeito)
export(scale_fill_pizza)
export(scale_fill_pizza_c)
export(scale_fill_pizza_d)
export(scale_fill_see)
export(scale_fill_see_c)
export(scale_fill_see_d)
export(scale_fill_social)
export(scale_fill_social_c)
export(scale_fill_social_d)
export(see_colors)
export(social_colors)
export(theme_abyss)
export(theme_blackboard)
export(theme_lucid)
export(theme_modern)
export(theme_radar)
export(theme_radar_dark)
import(ggplot2)
